<?php

/**
 * @file
 * Post update functions for conditions.
 */

use Drupal\conditions_field\Plugin\Field\FieldType\ConditionsItemInterface;
use Drupal\Core\Entity\Sql\SqlEntityStorageInterface;

/**
 * Implements hook_post_update_NAME().
 *
 * Adds a status column to all existing conditions fields.
 */
function conditions_post_update_add_status_columns_to_conditions_field(&$sandbox) {
  $definition_update_manager = \Drupal::entityDefinitionUpdateManager();
  /** @var \Drupal\Core\Entity\EntityLastInstalledSchemaRepositoryInterface $last_installed_schema_repository */
  $last_installed_schema_repository = \Drupal::service('entity.last_installed_schema.repository');

  $condition_fields = $field_types = [];

  // We need to update all conditions fields.
  // And also fields that inherit from it e.g. slots fields.
  /** @var \Drupal\Core\Field\FieldTypePluginManagerInterface $field_type_manager */
  $field_type_manager = \Drupal::service('plugin.manager.field.field_type');
  foreach ($field_type_manager->getDefinitions() as $definition) {
    if (is_subclass_of($field_type_manager->getPluginClass($definition['id']), ConditionsItemInterface::class)) {
      $field_types[] = $definition['id'];
    }
  }

  /** @var \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager */
  $entity_field_manager = \Drupal::service('entity_field.manager');
  foreach ($field_types as $field_type) {
    $condition_fields = array_merge($entity_field_manager->getFieldMapByFieldType($field_type), $condition_fields);
  }

  // Now update all fields that implement ConditionsItemInterface.
  foreach ($condition_fields as $entity_type_id => $fields) {
    $field_storage_definitions = $last_installed_schema_repository->getLastInstalledFieldStorageDefinitions($entity_type_id);
    $entity_type = $definition_update_manager->getEntityType($entity_type_id);

    // Update schema.
    $definition_update_manager->updateFieldableEntityType($entity_type, $field_storage_definitions, $sandbox);

    // Set default values.
    $storage = \Drupal::entityTypeManager()->getStorage($entity_type_id);
    if (!$storage instanceof SqlEntityStorageInterface) {
      continue;
    }
    $mapping = $storage->getTableMapping();
    foreach ($fields as $field_name => $definition) {
      foreach ($mapping->getTableNames() as $table_name) {
        if (in_array($field_name, $mapping->getFieldNames($table_name))) {
          \Drupal::database()->update($table_name)
            ->fields([
              $field_name . '_status' => 1,
            ])
            ->execute();
        }
      }
    }
  }

  return t('Conditions fields have been updated.');
}
